#!/usr/bin/env python
# Copyright (C) 2010 W. Trevor King <wking@drexel.edu>
#
# This file is part of SiteCorePy.
#
# SiteCorePy is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation, either version 2 of the License, or (at your
# option) any later version.
#
# SiteCorePy is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with SiteCorePy.  If not, see <http://www.gnu.org/licenses/>.

"""Move Professors from YAML -> Sitecore.

Professors will be created in:
  Content -> Drexel -> ? -> physics -> ?
"""

from selenium.common.exceptions import NoSuchElementException
import yaml

from .. import SiteCoreConnection
from . import Name, Graduation, Contact, Bio, Professor


class ProfessorAdder (object):
    """See doc/faculty.txt for Drexel's field/format policy.
    """
    def __init__(self, sitecore_connection):
        self.s = sitecore_connection

    def setup(self):
        s.expand_nav_section('Media Library')
        s.expand_nav_section('Images')
        s.expand_nav_section('physics')
        s.expand_nav_section('headshots')

    def __call__(self, prof):
        raw_name = TODO
        s.open_nav_section(raw_name)
        TODO

def main(argv):
    import optparse
    usage = """%prog [options] PROF_FILE

Where PROF_FILE is a YAML file containing professor data.

Example setup before running:
  Xvfb :99 > /dev/null 2>&1 &
  export DISPLAY=:99
  java -jar selenium-server-1.0.2-SNAPSHOT-standalone.jar > /dev/null 2>&1 &
  ./sc.py prof-import profs.yaml
"""
    p = optparse.OptionParser(usage)
    p.add_option('-u', '--url', metavar='URL', dest='url',
                 help='set the website URL (%default)',
                 default='https://webedit.drexel.edu/sitecore/login')
    p.add_option('-v', '--verbose', dest='verbose', action='count',
                 help='increment verbosity (%default)',
                 default=0)

    options,args = p.parse_args(argv)
    prof_file = args[0]
    profs = yaml.load(prof_file)

    s = SiteCoreConnection(options.url, options.verbose)
    s.start()
    try:
        s.login()
        a = ProfessorAdder(s)
        a.setup()
        for prof in profs:
            a.aadd_profs(s, profs)
    finally:
        s.stop()
